==> open-xchange-core_7.6.3.orig.tar.bz2: open-xchange-core-7.6.3/com.openexchange.startup.impl/src/com/openexchange/startup/impl/osgi/SignalStartedServiceActivator.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.startup.impl.osgi;

import org.osgi.framework.BundleActivator;
import org.osgi.framework.BundleContext;
import org.osgi.framework.ServiceRegistration;
import org.slf4j.Logger;
import com.openexchange.startup.SignalStartedService;
import com.openexchange.startup.impl.SignalStartedServiceImpl;

/**
 * {@link SignalStartedServiceActivator}
 *
 * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
 * @since v7.6.0
 */
public final class SignalStartedServiceActivator implements BundleActivator {

    private volatile ServiceRegistration<SignalStartedService> registration;

    /**
     * Initializes a new {@link SignalStartedServiceActivator}.
     */
    public SignalStartedServiceActivator() {
        super();
    }

    @Override
    public void start(BundleContext context) throws Exception {
        Logger logger = org.slf4j.LoggerFactory.getLogger(SignalStartedServiceActivator.class);
        try {
            registration = context.registerService(SignalStartedService.class, new SignalStartedServiceImpl(), null);
            logger.info("Open-Xchange Server initialized. The server should be up and running...");
        } catch (final Exception e) {
            logger.error("Error while starting bundle com.openexchange.startup.impl", e);
            throw e;
        }
    }

    @Override
    public void stop(BundleContext context) throws Exception {
        Logger logger = org.slf4j.LoggerFactory.getLogger(SignalStartedServiceActivator.class);
        try {
            ServiceRegistration<SignalStartedService> registration = this.registration;
            if (null != registration) {
                logger.info("Stopping Open-Xchange Server...");
                registration.unregister();
                this.registration = null;
            }
        } catch (final Exception e) {
            logger.error("Error while stopping bundle com.openexchange.startup.impl", e);
            throw e;
        }
    }

}

==> open-xchange-core_7.8.1.orig.tar.bz2: open-xchange-core-7.8.1/com.openexchange.startup.impl/src/com/openexchange/startup/impl/osgi/SignalStartedServiceActivator.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.startup.impl.osgi;

import java.util.concurrent.atomic.AtomicReference;
import org.osgi.framework.ServiceRegistration;
import com.openexchange.database.migration.DBMigrationMonitorService;
import com.openexchange.osgi.HousekeepingActivator;
import com.openexchange.startup.SignalStartedService;

/**
 * {@link SignalStartedServiceActivator}
 *
 * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
 * @since v7.6.0
 */
public final class SignalStartedServiceActivator extends HousekeepingActivator {

    private final AtomicReference<ServiceRegistration<SignalStartedService>> signalStartedRegistrationRef;

    /**
     * Initializes a new {@link SignalStartedServiceActivator}.
     */
    public SignalStartedServiceActivator() {
        super();
        signalStartedRegistrationRef = new AtomicReference<ServiceRegistration<SignalStartedService>>();
    }

    @Override
    protected Class<?>[] getNeededServices() {
        return EMPTY_CLASSES;
    }

    @Override
    protected void startBundle() throws Exception {
        track(DBMigrationMonitorService.class, new DBMigrationMonitorTracker(signalStartedRegistrationRef, context));
        openTrackers();
    }

    @Override
    protected void stopBundle() throws Exception {
        ServiceRegistration<SignalStartedService> signalStartedRegistration = signalStartedRegistrationRef.getAndSet(null);
        if (signalStartedRegistration != null) {
            signalStartedRegistration.unregister();
        }
        super.stopBundle();
    }

}
